Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/twbs/bootstrap.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/assets
diff options
context:
space:
mode:
authorXhmikosR <xhmikosr@gmail.com>2017-12-31 03:11:59 +0300
committerGitHub <noreply@github.com>2017-12-31 03:11:59 +0300
commite0e9bc8b5894c31557bfe7bc013707c887190c6b (patch)
treef9e86512ea031599d9bcb3bbc977c6f097deadb6 /assets
parentbf0e753517ab83a148088189b136375f21cb684d (diff)
Move inline JS outside of HTML. (#25140)
Diffstat (limited to 'assets')
-rw-r--r--assets/js/src/application.js32
1 files changed, 31 insertions, 1 deletions
diff --git a/assets/js/src/application.js b/assets/js/src/application.js
index eb52848756..d5ee22ebc3 100644
--- a/assets/js/src/application.js
+++ b/assets/js/src/application.js
@@ -10,7 +10,7 @@
* details, see https://creativecommons.org/licenses/by/3.0/.
*/
/* global Clipboard, anchors */
(function ($) {
'use strict'
@@ -101,5 +101,35 @@
}
anchors.add('.bd-content > h2, .bd-content > h3, .bd-content > h4, .bd-content > h5')
$('.bd-content > h2, .bd-content > h3, .bd-content > h4, .bd-content > h5').wrapInner('<div></div>')
+
+ // Search
+ if (window.docsearch) {
+ window.docsearch({
+ apiKey: '48cb48b22351bc71ea5f12f4d1ede198',
+ indexName: 'bootstrap-v4',
+ inputSelector: '#search-input',
+ handleSelected: function (input, event, suggestion) {
+ var url = suggestion.url
+ url = suggestion.isLvl1 ? url.split('#')[0] : url
+ // If it's a title we remove the anchor so it does not jump.
+ window.location.href = url
+ },
+ transformData: function (hits) {
+ return hits.map(function (hit) {
+ hit.url = hit.url.replace('https://v4-alpha.getbootstrap.com', '/docs/4.0')
+ return hit
+ })
+ },
+ debug: false // Set debug to true if you want to inspect the dropdown
+ })
+ }
+
+ // Holder
+ Holder.addTheme('gray', {
+ bg: '#777',
+ fg: 'rgba(255,255,255,.75)',
+ font: 'Helvetica',
+ fontweight: 'normal'
+ })
})
}(jQuery))
@@ -10,7 +10,7 @@
* details, see https://creativecommons.org/licenses/by/3.0/.
*/
-/* global Clipboard, anchors */
+/* global Clipboard: false, anchors: false, Holder: false */
(function ($) {
'use strict'